==> haskell-reducers-3.12.5-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-Eknitf5rkgZKJxZIgkcQSj
key:                  reducers-3.12.5-Eknitf5rkgZKJxZIgkcQSj
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  7f247324b19ec764b960e7c5dddceff0
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-Eknitf5rkgZKJxZIgkcQSj
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.6.2-FnEnpWQRyS2IIJ6ngDQdGp
    hashable-1.4.4.0-Htybuq5UDQvAvffgJDQoKe
    semigroupoids-6.0.1-90GKDoQoQ0l2R7V1Q3x2vH text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.5-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-7ob3I1VXJddBWd9UM3iFfM
key:                  reducers-3.12.5-7ob3I1VXJddBWd9UM3iFfM
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  ebd24e9e1158ed9a268fd800061807f0
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-7ob3I1VXJddBWd9UM3iFfM
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.6.2-7V7BwQU9500GtWVXtQewK3
    hashable-1.4.4.0-L4Cy5OzOiFo7EDda82f1f2
    semigroupoids-6.0.1-4CnZvgWKSH6LO3xaxoiG8y text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
